@@ -15,19 +15,20 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef _ANJUTA_SHELL_H
 #define _ANJUTA_SHELL_H
 
 #include <glib-object.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-plugin-manager.h>
+#include <libanjuta/anjuta-profile-manager.h>
 #include <libanjuta/anjuta-session.h>
 #include <libanjuta/anjuta-save-prompt.h>
 
@@ -63,13 +64,14 @@ struct _AnjutaShellIface {
 	GTypeInterface g_iface;
 	
 	/* Signals */
-	void (*value_added) (AnjutaShell *shell, char *name, GValue *value);
+	void (*value_added)  (AnjutaShell *shell, char *name, GValue *value);
 	void (*value_removed) (AnjutaShell *shell, char *name);
 	void (*save_session) (AnjutaShell *shell, AnjutaSessionPhase phase,
 						  AnjutaSession *session);
 	void (*load_session) (AnjutaShell *shell, AnjutaSessionPhase phase,
 						  AnjutaSession *session);
 	void (*save_prompt)  (AnjutaShell *shell, AnjutaSavePrompt *save_prompt);
+	void (*exiting)      (AnjutaShell *shell);
 	
 	/* Virtual Table */
 	AnjutaStatus* (*get_status) (AnjutaShell  *shell, GError **err);
@@ -77,14 +79,18 @@ struct _AnjutaShellIface {
 	AnjutaPreferences* (*get_preferences) (AnjutaShell *shell, GError **err);
 	AnjutaPluginManager* (*get_plugin_manager) (AnjutaShell *shell,
 												GError **err);
+	AnjutaProfileManager* (*get_profile_manager) (AnjutaShell *shell,
+												  GError **err);
 	
-	void (*add_widget)        (AnjutaShell  *shell,
+	void (*add_widget_full)        (AnjutaShell  *shell,
 							   GtkWidget    *widget,
 							   const char   *name,
 							   const char   *title,
 							   const char   *stock_id,
 							   AnjutaShellPlacement placement,
+							   gboolean locked,
 							   GError      **error);
+	
 	void (*remove_widget)     (AnjutaShell  *shell,
 							   GtkWidget    *widget,
 							   GError      **error);
@@ -102,6 +108,8 @@ struct _AnjutaShellIface {
 	void (*remove_value)      (AnjutaShell  *shell,
 							   const char   *name,
 							   GError       **error);
+	void (*saving_push)       (AnjutaShell* shell);
+	void (*saving_pop)        (AnjutaShell* shell);
 	GObject* (*get_object)    (AnjutaShell  *shell,
 							   const char   *iface_name,
 							   GError       **error);
@@ -120,6 +128,9 @@ AnjutaPreferences* anjuta_shell_get_preferences (AnjutaShell *shell,
 AnjutaPluginManager* anjuta_shell_get_plugin_manager (AnjutaShell *shell,
 													  GError **error);
 
+AnjutaProfileManager* anjuta_shell_get_profile_manager (AnjutaShell *shell,
+														GError **error);
+
 void anjuta_shell_freeze (AnjutaShell *shell, GError **error);
 void anjuta_shell_thaw (AnjutaShell *shell, GError **error);
 
@@ -130,6 +141,16 @@ void   anjuta_shell_add_widget      (AnjutaShell     *shell,
 									 const char      *stock_id,
 									 AnjutaShellPlacement placement,
 									 GError         **error);
+
+void   anjuta_shell_add_widget_full      (AnjutaShell     *shell,
+									 GtkWidget       *widget,
+									 const char      *name,
+									 const char      *title,
+									 const char      *stock_id,
+									 AnjutaShellPlacement placement,
+									 gboolean locked,
+									 GError         **error);
+
 void   anjuta_shell_remove_widget   (AnjutaShell     *shell,
 									 GtkWidget       *widget,
 									 GError         **error);
@@ -176,6 +197,10 @@ void anjuta_shell_session_load      (AnjutaShell *shell,
 void anjuta_shell_save_prompt       (AnjutaShell *shell,
 									 AnjutaSavePrompt *prompt,
 									 GError **error);
+void anjuta_shell_notify_exit       (AnjutaShell *shell, GError **error);
+void anjuta_shell_saving_push	    (AnjutaShell* shell);
+void anjuta_shell_saving_pop	    (AnjutaShell* shell);
+
 
 /**
  * anjuta_shell_get_interface:
