@@ -211,7 +211,6 @@ create_sharedlibs_gui (Sharedlibs *sl)
 	AnjutaUI *ui;
 	
 	window3 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_widget_set_usize (window3, 170, -2);
 	gtk_window_set_title (GTK_WINDOW (window3), _("Shared libraries"));
 	gtk_window_set_wmclass (GTK_WINDOW (window3), "sharedlibs", "Anjuta");
 	gtk_window_set_default_size (GTK_WINDOW (window3), 240, 230);
@@ -336,7 +335,7 @@ sharedlibs_new (DebugManagerPlugin *plugin)
 	sl->action_group = 
 		anjuta_ui_add_action_group_entries (ui,
 				"ActionGroupSharedlibs",
-				_("Sharedlibs operations"),
+				_("Shared library operations"),
 				sharedlibs_menu_actions,
 				G_N_ELEMENTS(sharedlibs_menu_actions),
 				GETTEXT_PACKAGE, TRUE, sl);
