@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Naba Kumar
  */
@@ -35,6 +35,8 @@
 
 #include <glib/gi18n.h>
 
+#include <libanjuta/anjuta-debug.h>
+
 #include "gbf-am-config.h"
 #include "gbf-am-properties.h"
 
@@ -269,7 +271,7 @@ save_packages_list (GbfAmProject *project, GbfAmConfigMapping *config,
 	    while (gtk_tree_model_iter_next (model, &child));
 	}
 	
-	if (strlen (packages_list->str) > 0)
+	if (packages_list->len > 0)
 	{
 		GbfAmConfigMapping *pkgmodule;
 		key_name = g_strconcat ("pkg_check_modules_",
@@ -302,8 +304,10 @@ save_packages_list (GbfAmProject *project, GbfAmConfigMapping *config,
 			gbf_am_config_value_set_string (value, packages_list->str);
 		}
 		g_free (key_name);
-	}
+	} 
 	g_free (module_name);
+	
+	g_string_free (packages_list, TRUE);
 }
 
 static void
@@ -427,6 +431,7 @@ add_package_clicked_cb (GtkWidget *button, GbfAmProject *project)
 							renderer,
 							"text", COL_PKG_PACKAGE,
 							NULL);
+	gtk_tree_view_column_set_sort_column_id (col, COL_PKG_PACKAGE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (pkg_treeview), col);
 	renderer = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("Version"),
@@ -524,7 +529,9 @@ remove_package_clicked_cb (GtkWidget *button, GbfAmProject *project)
 						  GTK_BUTTONS_YES_NO,
 						  msg, name);
 	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_YES)
+	{
 		gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+	}
 	gtk_widget_destroy (dlg);
 	g_free (name);
 	if (has_parent)
@@ -701,9 +708,11 @@ remove_variable_clicked_cb (GtkWidget *button, GtkWidget *top_level)
 		if (value)
 		{
 			variables = gbf_am_config_value_get_mapping (value);
-			value = gbf_am_config_value_new (GBF_AM_TYPE_STRING);
-			gbf_am_config_value_set_string (value, "");
-			gbf_am_config_mapping_insert (variables, name, value);
+			value = gbf_am_config_mapping_lookup (variables, name);
+			if (value)
+			{
+				gbf_am_config_value_set_string (value, NULL);
+			}
 		}
 		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 	}
@@ -914,6 +923,7 @@ gbf_am_properties_get_widget (GbfAmProject *project, GError **error)
 	col = gtk_tree_view_column_new_with_attributes (_("Module/Packages"),
 							renderer,
 							"text", 0, NULL);
+	gtk_tree_view_column_set_sort_column_id (col, 0);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), col);
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (G_OBJECT (renderer), "editable", TRUE, NULL);
@@ -955,6 +965,7 @@ gbf_am_properties_get_widget (GbfAmProject *project, GError **error)
 							renderer,
 							"text", 
 							COL_VAR_NAME, NULL);
+	gtk_tree_view_column_set_sort_column_id (col, COL_VAR_NAME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), col);
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (G_OBJECT (renderer), "editable", TRUE, NULL);
