@@ -138,8 +138,8 @@ on_macro_selection_changed (GtkTreeSelection * selection,
 				    MACRO_PREDEFINED, &predefined, -1);
 		if (!is_category)
 		{
-			details = g_strdup_printf ("Name:\t %s\n"
-						   "Category:\t %s\nShortcut:\t %c\n",
+			details = g_strdup_printf (_("Name:\t %s\n"
+						   "Category:\t %s\nShortcut:\t %c\n"),
 						   name, category, shortcut);
 			/* Keep pango happy */
 			details_utf8 = g_utf8_normalize (details, -1,
@@ -323,6 +323,8 @@ macro_dialog_new (MacroPlugin * plugin)
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (on_dialog_response), plugin);
+	g_signal_connect (G_OBJECT(dialog), "delete-event",
+			G_CALLBACK(gtk_widget_hide_on_delete), NULL);	
 	g_signal_connect(G_OBJECT(dialog), "key-press-event",
 			G_CALLBACK(on_macro_dialog_key_press_event), plugin);
 	
