@@ -28,6 +28,7 @@
 #include <libanjuta/interfaces/ianjuta-vcs.h>
 
 #include "plugin.h"
+#include "subversion-vcs-interface.h"
 #include "subversion-add-dialog.h"
 #include "subversion-remove-dialog.h"
 #include "subversion-commit-dialog.h"
@@ -160,6 +161,14 @@ static GtkActionEntry popup_actions_subversion[] = {
 		N_("Sync your local copy with the Subversion tree"),                      /* Tooltip */
 		G_CALLBACK (on_fm_subversion_update)    /* action callback */
 	},
+	{
+		"ActionPopupSubversionRevert",                       /* Action name */
+		GTK_STOCK_UNDO,                            /* Stock icon, if any */
+		N_("_Revert..."),                     /* Display label */
+		NULL,                                     /* short-cut */
+		N_("Revert changes to your working copy."),                      /* Tooltip */
+		G_CALLBACK (on_fm_subversion_revert)    /* action callback */
+	},
 	{
 		"ActionPopupSubversionAdd",                       /* Action name */
 		GTK_STOCK_ADD,                            /* Stock icon, if any */
@@ -213,6 +222,7 @@ value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 	GFile* svn_dir;
 	GFileType type;
 	GFileEnumerator *en;
+	GFileInfo *file_info;
 	
 	file = G_FILE(g_value_get_object (value));
 	filename = g_file_get_path (file);
@@ -230,7 +240,18 @@ value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 	
 	/* If a directory is selected we check if it contains a "Subversion" directory,
 	if it is a file we check if it's directory contains a "Subversion" directory */
-	type = g_file_query_file_type (file, G_FILE_QUERY_INFO_NONE, NULL);
+	file_info = g_file_query_info (file, 
+			G_FILE_ATTRIBUTE_STANDARD_TYPE,
+			G_FILE_QUERY_INFO_NONE,
+			NULL, NULL);
+	if (file_info == NULL)
+	{
+		return;
+	}
+
+	type = g_file_info_get_attribute_uint32 (file_info, 
+			G_FILE_ATTRIBUTE_STANDARD_TYPE);
+	g_object_unref (G_OBJECT (file_info));
 	if (type == G_FILE_TYPE_DIRECTORY)
 	{
 		svn_dir = g_file_get_child (file, ".svn");
@@ -560,6 +581,7 @@ subversion_class_init (GObjectClass *klass)
 }
 
 ANJUTA_PLUGIN_BEGIN (Subversion, subversion);
+ANJUTA_PLUGIN_ADD_INTERFACE (subversion_ivcs, IANJUTA_TYPE_VCS);
 ANJUTA_PLUGIN_END;
 
 ANJUTA_SIMPLE_PLUGIN (Subversion, subversion);
