@@ -14,7 +14,7 @@
  * for more details.
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc., 59 
- * Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,7 +52,19 @@ on_exit_activate (GtkAction *action, AnjutaTestShell *shell)
 static void
 on_preferences_activate (GtkAction *action, AnjutaTestShell *shell)
 {
-	gtk_widget_show (GTK_WIDGET (shell->preferences));
+	GtkWidget *preferences_dialog;
+	
+	preferences_dialog = anjuta_preferences_get_dialog (shell->preferences);
+		
+	g_signal_connect_swapped (G_OBJECT (preferences_dialog),
+					  		  "response",
+					  		  G_CALLBACK (gtk_widget_destroy),
+					  		  preferences_dialog); 
+	
+	gtk_window_set_transient_for (GTK_WINDOW (preferences_dialog),
+								  GTK_WINDOW (shell));
+								  
+	gtk_widget_show (preferences_dialog);
 }
 
 static void
@@ -108,7 +120,7 @@ static void
 on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 					 GtkWidget *ui_container)
 {
-	DEBUG_PRINT ("Adding UI item...");
+	DEBUG_PRINT ("%s", "Adding UI item...");
 	gtk_box_pack_start (GTK_BOX ((ANJUTA_TEST_SHELL (ui_container))->box),
 						 widget, FALSE, FALSE, 0);
 }
@@ -150,11 +162,11 @@ anjuta_test_shell_instance_init (AnjutaTestShell *shell)
 													   plugins_dirs);
 	g_list_free (plugins_dirs);
 	
-	plugins = anjuta_plugin_manager_get_dialog (shell->plugin_manager);
+	plugins = anjuta_plugin_manager_get_plugins_page (shell->plugin_manager);
 	gtk_box_pack_end_defaults (GTK_BOX (shell->box), plugins);
 	
 	/* Preferencesnces */
-	shell->preferences = ANJUTA_PREFERENCES (anjuta_preferences_new ());
+	shell->preferences = ANJUTA_PREFERENCES (anjuta_preferences_new (shell->plugin_manager));
 	
 	/* UI engine */
 	shell->ui = anjuta_ui_new ();
@@ -164,8 +176,8 @@ anjuta_test_shell_instance_init (AnjutaTestShell *shell)
 					  "add_widget", G_CALLBACK (on_add_merge_widget),
 					  shell);
 	
-	gtk_window_add_accel_group (GTK_WINDOW (shell),
-								anjuta_ui_get_accel_group (shell->ui));
+	/*gtk_window_add_accel_group (GTK_WINDOW (shell),
+	 						anjuta_ui_get_accel_group (shell->ui));*/
 	/* Register actions */
 	anjuta_ui_add_action_group_entries (shell->ui, "ActionGroupTestShell",
 										_("Test shell action group"),
@@ -229,6 +241,7 @@ anjuta_test_shell_add_widget (AnjutaShell *shell,
 							   const char *title,
 							   const char *stock_id,
 							   AnjutaShellPlacement placement,
+							   gboolean locked,
 							   GError **error)
 {
 	GtkWidget *client_win;
@@ -279,6 +292,12 @@ anjuta_test_shell_remove_widget (AnjutaShell *shell,
 	//}
 }
 
+static AnjutaPluginManager*
+anjuta_test_shell_get_plugin_manager (AnjutaShell *shell, GError **error)
+{
+	return ANJUTA_TEST_SHELL(shell)->plugin_manager;
+}
+
 static void 
 anjuta_test_shell_present_widget (AnjutaShell *shell, 
 								  GtkWidget *w, 
@@ -381,7 +400,7 @@ anjuta_test_shell_class_init (AnjutaTestShellClass *class)
 static void
 anjuta_shell_iface_init (AnjutaShellIface *iface)
 {
-	iface->add_widget = anjuta_test_shell_add_widget;
+	iface->add_widget_full = anjuta_test_shell_add_widget;
 	iface->remove_widget = anjuta_test_shell_remove_widget;
 	iface->present_widget = anjuta_test_shell_present_widget;
 	iface->add_value = anjuta_test_shell_add_value;
@@ -391,6 +410,7 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_status = anjuta_test_shell_get_status;
 	iface->get_ui = anjuta_test_shell_get_ui;
 	iface->get_preferences = anjuta_test_shell_get_preferences;
+	iface->get_plugin_manager = anjuta_test_shell_get_plugin_manager;
 }
 
 ANJUTA_TYPE_BEGIN(AnjutaTestShell, anjuta_test_shell, GTK_TYPE_WINDOW);
